summaryrefslogtreecommitdiff
path: root/plugins/pychrysalide/glibext/constants.h
diff options
context:
space:
mode:
authorCyrille Bagard <nocbos@gmail.com>2020-07-14 13:06:20 (GMT)
committerCyrille Bagard <nocbos@gmail.com>2020-07-14 13:06:20 (GMT)
commit6c751d40ab1b84a6979c143ed47702207edebed8 (patch)
treee789491530d641f89e574f8eacb4f0e66bd93a91 /plugins/pychrysalide/glibext/constants.h
parentde82c8165e61e3c19be184dbc00f66bfc7479c76 (diff)
Updated the Python bindings for the loaded panel interface.
Diffstat (limited to 'plugins/pychrysalide/glibext/constants.h')
-rw-r--r--plugins/pychrysalide/glibext/constants.h14
1 files changed, 10 insertions, 4 deletions
diff --git a/plugins/pychrysalide/glibext/constants.h b/plugins/pychrysalide/glibext/constants.h
index b815586..f509866 100644
--- a/plugins/pychrysalide/glibext/constants.h
+++ b/plugins/pychrysalide/glibext/constants.h
@@ -37,17 +37,23 @@ bool define_binary_portion_constants(PyTypeObject *);
/* Tente de convertir en constante PortionAccessRights. */
int convert_to_portion_access_rights(PyObject *, void *);
+/* Définit les constantes relatives aux lignes de tampon. */
+bool define_buffer_line_constants(PyTypeObject *);
+
+/* Tente de convertir en constante BufferLineFlags. */
+int convert_to_buffer_line_flags(PyObject *, void *);
+
/* Définit les constantes relatives aux segments de ligne. */
bool define_line_segment_constants(PyTypeObject *);
/* Tente de convertir en constante RenderingTagType. */
int convert_to_rendering_tag_type(PyObject *, void *);
-/* Définit les constantes relatives aux lignes de tampon. */
-bool define_buffer_line_constants(PyTypeObject *);
+/* Définit les constantes relatives aux panneaux de chargement. */
+bool define_loaded_panel_constants(PyTypeObject *);
-/* Tente de convertir en constante BufferLineFlags. */
-int convert_to_buffer_line_flags(PyObject *, void *);
+/* Tente de convertir en constante ScrollPositionTweak. */
+int convert_to_scroll_position_tweak(PyObject *, void *);